Coverage report

File |  | statements | missing | excluded |  | coverage
--- | --- | --- | --- | --- | --- | ---
savcfg / __init__.py |  | 2 | 0 | 0 |  | 100%
savcfg / bootstrap.py |  | 29 | 0 | 0 |  | 100%
savcfg / core.py |  | 52 | 24 | 0 |  | 54%
savcfg / edit.py |  | 17 | 0 | 10 |  | 100%
savcfg / keyvault.py |  | 34 | 1 | 0 |  | 97%
savcfg / read.py |  | 48 | 5 | 0 |  | 90%
Total |  | 182 | 30 | 10 |  | 84%

No items found using the specified filter.